@@ -81,7 +81,7 @@ Q_OBJECT
 public:
     kpColorCells (QWidget *parent,
                   Qt::Orientation o = Qt::Horizontal);
-    virtual ~kpColorCells ();
+    ~kpColorCells () override;
 
     static kpColorCollection DefaultColorCollection ();
 
@@ -154,7 +154,7 @@ signals:
     void isModifiedChanged (bool isModified);
 
 protected:
-    virtual void contextMenuEvent (QContextMenuEvent *e);
+    void contextMenuEvent (QContextMenuEvent *e) override;
 
 protected slots:
     void slotColorSelected (int cell, const QColor &color, Qt::MouseButton button);
